@@ -6,7 +6,7 @@ use warnings;
 use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -18,6 +18,9 @@ sub new {
 	# 'CSS::Struct::Output' object.
 	$self->{'css'} = undef;
 
+	# No CSS support.
+	$self->{'no_css'} = 0;
+
 	# 'Tags::Output' object.
 	$self->{'tags'} = undef;
 
@@ -25,7 +28,9 @@ sub new {
 	set_params($self, @params);
 
 	# Check to 'CSS::Struct::Output' object.
-	if (defined $self->{'css'} && ! $self->{'css'}->isa('CSS::Struct::Output')) {
+	if (! $self->{'no_css'} && defined $self->{'css'}
+		&& ! $self->{'css'}->isa('CSS::Struct::Output')) {
+
 		err "Parameter 'css' must be a 'CSS::Struct::Output::*' class.";
 	}
 
@@ -55,6 +60,11 @@ sub process {
 sub process_css {
 	my ($self, @params) = @_;
 
+	# No CSS support.
+	if ($self->{'no_css'}) {
+		return;
+	}
+
 	if (! defined $self->{'css'}) {
 		err "Parameter 'css' isn't defined.";
 	}
@@ -118,6 +128,13 @@ Returns instance of class.
 
 Default value is undef.
 
+=item * C<no_css>
+
+No CSS support flag.
+If this flag is set to 1, L<process_css()> returns undef.
+
+Default value is 0.
+
 =item * C<tags>
 
 'Tags::Output' object for L<process> processing.
@@ -242,12 +259,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2021
+© Michal Josef Špaček 2021-2022
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
